"""
MCP server for FOLIO, the Federated Open Legal Information Ontology
"""

# SPDX-License-Identifier: MIT
# (c) 2024 ALEA Institute.

__version__ = "0.2.0"
__author__ = "ALEA Institute"
__license__ = "MIT"
__description__ = "MCP server for FOLIO, the Federated Open Legal Information Ontology"
__url__ = "https://openlegalstandard.org/"
